.. _Authentication:

Authentication
==============

Authentication process works through "user token" and "chat token". Each Api request has such required parameters:

* "chat token" that identify chat
* "user token" that helps to identify user

For details please follow :ref:`diagrams <Diagrams>`.
